.. _profile_show:

**show** - Detail a specific profile
====================================

Usage
------

.. code::

    e4s-cl profile show [ NAME ]

Description
--------------

.. automodule:: e4s_cl.cli.commands.profile.show
